@@ -17,6 +17,10 @@
 using FileSize = quint64;
 
 class Folder;
+namespace RadialMap
+{
+class Segment;
+} // namespace RadialMap
 
 class File
 {
@@ -35,6 +39,17 @@ public:
     File(File &&) = default;
     File &operator=(File &&) = default;
 
+    QString segment() const
+    {
+        return m_segment;
+    }
+
+    void setSegment(const QString &segment)
+    {
+        Q_ASSERT(m_segment.isEmpty() || segment.isEmpty());
+        m_segment = segment;
+    }
+
     Folder *parent() const
     {
         return m_parent;
@@ -94,6 +109,8 @@ protected:
     Folder *m_parent; // 0 if this is treeRoot; this is a non-owning pointer, the parent owns "us"
     QByteArray m_name; // partial path name (e.g. 'boot/' or 'foo.svg')
     FileSize m_size; // in units of bytes; sum of all children's sizes
+
+    QString m_segment;
 };
 
 class Folder : public File
@@ -104,7 +121,7 @@ public:
     {
     } // DON'T pass the full path!
 
-    ~Folder();
+    ~Folder() override;
     Folder(const Folder &) = default;
     Folder &operator=(const Folder &) = default;
     Folder(Folder &&) = default;
