@@ -1,12 +1,11 @@
 /***********************************************************************
-* SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
-* SPDX-FileCopyrightText: 2008-2014 Martin Sandsmark <martin.sandsmark@kde.org>
-*
-* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-***********************************************************************/
+ * SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
+ * SPDX-FileCopyrightText: 2008-2014 Martin Sandsmark <martin.sandsmark@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ ***********************************************************************/
 
-#ifndef HISTORYACTION_H
-#define HISTORYACTION_H
+#pragma once
 
 #include <QAction>
 #include <QUrl>
@@ -23,18 +22,20 @@ class HistoryAction : QAction
     friend class HistoryCollection;
 
 public:
-    virtual void setEnabled(bool b = true) {
+    virtual void setEnabled(bool b = true)
+    {
         QAction::setEnabled(b && !m_list.isEmpty());
     }
 
-    void clear() {
+    void clear()
+    {
         m_list.clear();
         setEnabled(false);
         QAction::setText(m_text);
     }
 
 private:
-    void setHelpText(const QUrl& url);
+    void setHelpText(const QUrl &url);
 
     void push(const QUrl &url);
     QUrl pop();
@@ -43,7 +44,6 @@ private:
     QList<QUrl> m_list;
 };
 
-
 class HistoryCollection : public QObject
 {
     Q_OBJECT
@@ -55,13 +55,14 @@ public:
     void restore(const KConfigGroup &configgroup);
 
 public Q_SLOTS:
-    void push(const QUrl& url);
-    void stop() {
+    void push(const QUrl &url);
+    void stop()
+    {
         m_receiver = nullptr;
     }
 
 Q_SIGNALS:
-    void activated(const QUrl&);
+    void activated(const QUrl &);
 
 private Q_SLOTS:
     void pop();
@@ -69,5 +70,3 @@ private Q_SLOTS:
 private:
     HistoryAction *m_b, *m_f, *m_receiver;
 };
-
-#endif
